# -----------------------------------------------------------
# This script provides ancilarry tools for geo data.
#
# Vincent Verbavatz - 2020
# -----------------------------------------------------------

from osgeo import gdal, ogr, osr

nameField = ogr.FieldDefn('Name', ogr.OFTString)
typeField = ogr.FieldDefn('Type', ogr.OFTInteger)
popField = ogr.FieldDefn('Population', ogr.OFTReal)
densityField = ogr.FieldDefn('Density', ogr.OFTReal)

def createBuffer(inputlyr, bufferlyr, bufferDist):
    """
    Inspired from the Python GDAL/OGR Cookbook, licensed under the MIT license.
    This recipe buffers features of a layer and saves them to a new Layer.
    """
    featureDefn = bufferlyr.GetLayerDefn()

    newGeometry = None

    for i in range(len(inputlyr)):
        feature = inputlyr[i]
        ingeom = feature.GetGeometryRef()
        geomBuffer = ingeom.Buffer(bufferDist)

        if newGeometry is None:
            newGeometry = geomBuffer.Clone()
        else:
            newGeometry = newGeometry.Union(geomBuffer)

    outFeature = ogr.Feature(featureDefn)
    outFeature.SetGeometry(newGeometry)
    bufferlyr.CreateFeature(outFeature)
    outFeature = None

def inverse_density(layer):
    """
    Calculates population from density field.
    """
    for i in range(len(layer)):
        feature = layer[i]
        ingeom = feature.GetGeometryRef()
        area = ingeom.GetArea()
        feature.SetField('Population', feature.GetField('Density') * area)
        layer.SetFeature(feature)

def sum_pop(layer):
    """
    Sums up feature populations of a layer
    """
    pop = 0
    for feature in layer:
        pop += feature.GetField('Population')

    return pop
